'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_vertex_array_range'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_vertex_array_range',error_checker=_errors._error_checker)
GL_MAX_VERTEX_ARRAY_RANGE_ELEMENT_NV=_C('GL_MAX_VERTEX_ARRAY_RANGE_ELEMENT_NV',0x8520)
GL_VERTEX_ARRAY_RANGE_LENGTH_NV=_C('GL_VERTEX_ARRAY_RANGE_LENGTH_NV',0x851E)
GL_VERTEX_ARRAY_RANGE_NV=_C('GL_VERTEX_ARRAY_RANGE_NV',0x851D)
GL_VERTEX_ARRAY_RANGE_POINTER_NV=_C('GL_VERTEX_ARRAY_RANGE_POINTER_NV',0x8521)
GL_VERTEX_ARRAY_RANGE_VALID_NV=_C('GL_VERTEX_ARRAY_RANGE_VALID_NV',0x851F)
@_f
@_p.types(None,)
def glFlushVertexArrayRangeNV():pass
@_f
@_p.types(None,_cs.GLsizei,ctypes.c_void_p)
def glVertexArrayRangeNV(length,pointer):pass
