'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_DFX_multisample'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_DFX_multisample',error_checker=_errors._error_checker)
GL_MULTISAMPLE_3DFX=_C('GL_MULTISAMPLE_3DFX',0x86B2)
GL_MULTISAMPLE_BIT_3DFX=_C('GL_MULTISAMPLE_BIT_3DFX',0x20000000)
GL_SAMPLES_3DFX=_C('GL_SAMPLES_3DFX',0x86B4)
GL_SAMPLE_BUFFERS_3DFX=_C('GL_SAMPLE_BUFFERS_3DFX',0x86B3)

